Mapping
=======

.. currentmodule:: semra.struct

.. autoclass:: Mapping
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Mapping.has_primary
      ~Mapping.has_secondary
      ~Mapping.has_tertiary
      ~Mapping.model_computed_fields
      ~Mapping.model_config
      ~Mapping.model_fields
      ~Mapping.triple

   .. rubric:: Methods Summary

   .. autosummary::

      ~Mapping.from_triple
      ~Mapping.get_confidence
      ~Mapping.key

   .. rubric:: Attributes Documentation

   .. autoattribute:: has_primary
   .. autoattribute:: has_secondary
   .. autoattribute:: has_tertiary
   .. autoattribute:: model_computed_fields
   .. autoattribute:: model_config
   .. autoattribute:: model_fields
   .. autoattribute:: triple

   .. rubric:: Methods Documentation

   .. automethod:: from_triple
   .. automethod:: get_confidence
   .. automethod:: key
